@@ -33,11 +33,23 @@ def tplot_names(quiet=False):
     # TODO: Print out links as well?
 
     for key, _ in data_quants.items():
+        if isinstance(data_quants[key], dict):
+            # non-record varying variables are stored as dictionaries
+            if isinstance(key, str):
+                names_to_print = key
+
+            if quiet != True:
+                print(index, ":", names_to_print)
+
+            return_names.append(names_to_print)
+            index += 1
+            continue
+
         if len(data_quants[key].attrs['plot_options']['overplots']) != 0:
             names_to_print = data_quants[key].name + "  data from: "
             for oplot_name in data_quants[key].attrs['plot_options']['overplots']:
                 names_to_print = names_to_print + " " + oplot_name
-            index+=1
+
         else:
             if isinstance(key, str):
                 names_to_print = data_quants[key].name
